`include "mock_turtle_driver.svh"
`include "vhd_wishbone_master.svh"

`timescale 1ns/1ps

module main;

   reg rst_n = 0;
   reg clk_125m = 0;

   always #4ns clk_125m <= ~clk_125m;

   initial begin
      repeat(20) @(posedge clk_125m);
      rst_n = 1;
   end

   // the Device Under Test
   svec_mt_demo #
     (
      .g_sim_bypass_vme(1)
      )
   DUT
     (
      .rst_n_a_i           (rst_n),
      .clk_125m_pllref_p_i (clk_125m),
      .clk_125m_pllref_n_i (~clk_125m),
      .fp_led_line_oen_o   (),
      .fp_led_line_o       (),
      .fp_led_column_o     (),
      .fp_gpio1_a2b_o      (),
      .fp_gpio2_a2b_o      (),
      .fp_gpio34_a2b_o     (),
      .fp_gpio1_b          (),
      .fp_gpio2_b          (),
      .fp_gpio3_b          (),
      .fp_gpio4_b          (),
      .sim_wb_i            (Host.out),
      .sim_wb_o            (Host.in),
      .VME_AS_n_i          (),
      .VME_RST_n_i         (),
      .VME_WRITE_n_i       (),
      .VME_AM_i            (),
      .VME_DS_n_i          (),
      .VME_GA_i            (),
      .VME_BERR_o          (),
      .VME_DTACK_n_o       (),
      .VME_RETRY_n_o       (),
      .VME_RETRY_OE_o      (),
      .VME_LWORD_n_b       (),
      .VME_ADDR_b          (),
      .VME_DATA_b          (),
      .VME_BBSY_n_i        (),
      .VME_IRQ_n_o         (),
      .VME_IACK_n_i        (),
      .VME_IACKIN_n_i      (),
      .VME_IACKOUT_n_o     (),
      .VME_DTACK_OE_o      (),
      .VME_DATA_DIR_o      (),
      .VME_DATA_OE_N_o     (),
      .VME_ADDR_DIR_o      (),
      .VME_ADDR_OE_N_o     ());


   IVHDWishboneMaster Host
     (
      .clk_i   (DUT.clk_sys),
      .rst_n_i (DUT.rst_n_sys));


   initial begin

      automatic CWishboneAccessor acc;
      automatic MockTurtleDriver drv;

      @(posedge DUT.rst_n_sys);
      @(posedge DUT.clk_sys);

      acc = Host.get_accessor();
      acc.set_mode (PIPELINED);

      drv = new(acc, 'h20000);

      drv.init();

      drv.cfg_rom_display();

      drv.load_firmware(0, "../sw/hello/hello.ram.urv");
      drv.reset_core(0, 0);

      forever begin
	 drv.update();
	 #1us;
      end

   end

endmodule // main
