/**
 * @defgroup framework-action Framework Action
 * @{
 * @ingroup framework
 * @brief Action (RPC)
 * @copyright (C) 2015-2016 CERN (www.cern.ch)
 * @author Federico Vaga <federico.vaga@cern.ch>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Library General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __TRTL_FW_FRM_ACTION_H__
#define __TRTL_FW_FRM_ACTION_H__

/**
 * Action prototype type
 * @param[in] hin input message header
 * @param[in] pin input message payload
 * @param[out] hout output message header
 * @param[out] pout output message payload
 * @return 0 on success. -1 on error
 */
typedef int (action_t)(struct trtl_proto_header *hin, void *pin,
		       struct trtl_proto_header *hout, void *pout);

/**
 * This is an @ref action_t function type. It fills the output payload
 * with an acknowledged message
 */
static inline void rt_send_ack(struct trtl_proto_header *hin, void *pin,
			       struct trtl_proto_header *hout, void *pout)
{
	hout->msg_id = TRTL_MSG_ID_ACK;
	hout->len = 0;
}

/**
 * This is an @ref action_t function type. It fills the output payload
 * with a not-acknowledged message
 */
static inline void rt_send_nack(struct trtl_proto_header *hin, void *pin,
				struct trtl_proto_header *hout, void *pout)
{
	hout->msg_id = TRTL_MSG_ID_NACK;
	hout->len = 0;
}

extern int rt_recv_ping(struct trtl_proto_header *hin, void *pin,
			struct trtl_proto_header *hout, void *pout);
extern int rt_version_getter(struct trtl_proto_header *hin, void *pin,
			     struct trtl_proto_header *hout, void *pout);
extern int rt_variable_setter(struct trtl_proto_header *hin, void *pin,
			    struct trtl_proto_header *hout, void *pout);
extern int rt_variable_getter(struct trtl_proto_header *hin, void *pin,
			    struct trtl_proto_header *hout, void *pout);
extern int rt_buffer_setter(struct trtl_proto_header *hin, void *pin,
			       struct trtl_proto_header *hout, void *pout);
extern int rt_buffer_getter(struct trtl_proto_header *hin, void *pin,
			       struct trtl_proto_header *hout, void *pout);
extern int rt_mq_action_dispatch(unsigned int mq_in);

#endif
/**@}*/
